@@ -27,11 +27,6 @@
 #include <string.h>
 #include <stdlib.h>
 
-#ifdef HAVE_GETAUXVAL
-#include <unistd.h>
-#include <sys/auxv.h>
-#endif
-
 #include <glib.h>
 #include <glib/gprintf.h>
 #include <gmodule.h>
@@ -152,14 +147,6 @@ init_globals (void)
   if (!g_once_init_enter (&initialized))
     return;
 
-#ifdef HAVE_GETAUXVAL
-  if (getauxval (AT_SECURE))
-    {
-      g_printerr ("error: libgirepository.so (gobject-introspection) is not audited for use in setuid applications\nSee https://bugzilla.gnome.org/show_bug.cgi?id=755472\n");
-      _exit (1);
-    }
-#endif
-
   if (default_repository == NULL)
     default_repository = g_object_new (G_TYPE_IREPOSITORY, NULL);
 
@@ -559,12 +546,12 @@ g_irepository_get_dependencies (GIRepository *repository,
   g_return_val_if_fail (namespace != NULL, NULL);
 
   repository = get_repository (repository);
-  transitive_dependencies = g_hash_table_new_full (g_str_hash, g_str_equal,
-                                                   g_free, NULL);
 
-  /* Load the dependencies. */
   typelib = get_registered (repository, namespace, NULL);
   g_return_val_if_fail (typelib != NULL, NULL);
+
+  /* Load the dependencies. */
+  transitive_dependencies = g_hash_table_new (g_str_hash, g_str_equal);
   get_typelib_dependencies_transitive (repository, typelib,
                                        transitive_dependencies);
 
@@ -579,6 +566,8 @@ g_irepository_get_dependencies (GIRepository *repository,
       g_hash_table_iter_steal (&iter);
     }
 
+  g_hash_table_unref (transitive_dependencies);
+
   /* Add a NULL terminator. */
   g_ptr_array_add (out, NULL);
 
