@@ -18,6 +18,10 @@
 # 02110-1301, USA.
 #
 
+from __future__ import absolute_import
+from __future__ import division
+from __future__ import print_function
+from __future__ import unicode_literals
 
 from .counter import Counter
 from .ordereddict import OrderedDict
